@@ -121,6 +121,23 @@ impl TargetMatcher for target_lexicon::Triple {
                 } else if arch == &targ::Arch::bpf {
                     self.architecture == Architecture::Bpfeb
                         || self.architecture == Architecture::Bpfel
+                } else if arch == &targ::Arch::x86_64 {
+                    self.architecture == Architecture::X86_64
+                        || self.architecture == Architecture::X86_64h
+                } else if arch == &targ::Arch::mips32r6 {
+                    matches!(
+                        self.architecture,
+                        Architecture::Mips32(
+                            Mips32Architecture::Mipsisa32r6 | Mips32Architecture::Mipsisa32r6el
+                        )
+                    )
+                } else if arch == &targ::Arch::mips64r6 {
+                    matches!(
+                        self.architecture,
+                        Architecture::Mips64(
+                            Mips64Architecture::Mipsisa64r6 | Mips64Architecture::Mipsisa64r6el
+                        )
+                    )
                 } else {
                     match arch.0.parse::<Architecture>() {
                         Ok(a) => match (self.architecture, a) {
@@ -224,6 +241,11 @@ impl TargetMatcher for target_lexicon::Triple {
                                                 | Environment::Uclibceabi
                                                 | Environment::Uclibceabihf
                                         )
+                                    } else if env == &targ::Env::newlib {
+                                        matches!(
+                                            self.operating_system,
+                                            OperatingSystem::Horizon | OperatingSystem::Espidf
+                                        )
                                     } else {
                                         self.environment == e
                                     }
@@ -235,7 +257,7 @@ impl TargetMatcher for target_lexicon::Triple {
                 }
             }
             Family(fam) => {
-                use target_lexicon::OperatingSystem::{
+                use OperatingSystem::{
                     Aix, AmdHsa, Bitrig, Cloudabi, Cuda, Darwin, Dragonfly, Emscripten, Espidf,
                     Freebsd, Fuchsia, Haiku, Hermit, Horizon, Illumos, Ios, L4re, Linux, MacOSX,
                     Nebulet, Netbsd, None_, Openbsd, Redox, Solaris, Tvos, Uefi, Unknown, VxWorks,
@@ -324,7 +346,15 @@ impl TargetMatcher for target_lexicon::Triple {
                 false
             }
             Vendor(ven) => match ven.0.parse::<target_lexicon::Vendor>() {
-                Ok(v) => self.vendor == v,
+                Ok(v) => {
+                    if self.vendor == v {
+                        true
+                    } else if let target_lexicon::Vendor::Custom(custom) = &self.vendor {
+                        custom.as_str() == "esp" && v == target_lexicon::Vendor::Espressif
+                    } else {
+                        false
+                    }
+                }
                 Err(_) => false,
             },
             PointerWidth(pw) => {
@@ -628,7 +658,7 @@ impl Expression {
     }
 }
 
-/// [`PartialEq`] will do a **syntactical** comparaison, so will just check if both
+/// [`PartialEq`] will do a **syntactical** comparison, so will just check if both
 /// expressions have been parsed from the same string, **not** if they are semantically
 /// equivalent.
 ///
